==> activiti-rpc-0.1.15-sources.jar: com/biz/eisp/activiti/vo/StartProcessParamVO.java <==
package com.biz.eisp.activiti.vo;

import java.io.Serializable;
import java.util.Collection;
import java.util.List;

/**
 * Created by weston on 2017/6/8.
 */
public class StartProcessParamVO implements Serializable{
    private static final long serialVersionUID = -3243637468050937453L;
    private String formNo;
    private String currentUser;
    private String costType;
    private String formType;
    private String positionCode;
    private String formUrl;
    private String title;
    private String smallType;
    private List<String> parentFormNos;

    public String printStr(){
        StringBuffer buffer = new StringBuffer();
        if(this.formNo != null){
            buffer.append(new StringBuffer(this.formNo));
        }
        if(this.currentUser != null){
            buffer.append(new StringBuffer("|").append(new StringBuffer(this.currentUser)));
        }
        if(this.costType != null){
            buffer.append(new StringBuffer("|").append(new StringBuffer(this.costType)));
        }
        if(this.formType != null){
            buffer.append(new StringBuffer("|").append(new StringBuffer(this.formType)));
        }
        if(this.positionCode != null){
            buffer.append(new StringBuffer("|").append(new StringBuffer(this.positionCode)));
        }
        if(this.formUrl != null){
            buffer.append(new StringBuffer("|").append(new StringBuffer(this.formUrl)));
        }
        if(this.title != null){
            buffer.append(new StringBuffer("|").append(new StringBuffer(this.title)));
        }
        if(this.smallType != null){
            buffer.append(new StringBuffer("|").append(new StringBuffer(this.smallType)));
        }
        buffer.append(new StringBuffer("|parentList:"));
        if(this.parentFormNos == null){
            buffer.append(new StringBuffer("null"));
        }else{
            int size = this.parentFormNos.size();
            buffer.append(new StringBuffer("size-")).append(new StringBuffer(size));
            if(size > 0 ){
                for (String parentFormNo : this.parentFormNos) {
                    buffer.append(new StringBuffer(",")).append(parentFormNo);
                }
            }
        }
        return buffer.toString();
    }

    public String getFormNo() {
        return formNo;
    }

    public void setFormNo(String formNo) {
        this.formNo = formNo;
    }

    public String getCurrentUser() {
        return currentUser;
    }

    public void setCurrentUser(String currentUser) {
        this.currentUser = currentUser;
    }

    public String getCostType() {
        return costType;
    }

    public void setCostType(String costType) {
        this.costType = costType;
    }

    public String getFormType() {
        return formType;
    }

    public void setFormType(String formType) {
        this.formType = formType;
    }

    public String getPositionCode() {
        return positionCode;
    }

    public void setPositionCode(String positionCode) {
        this.positionCode = positionCode;
    }

    public String getFormUrl() {
        return formUrl;
    }

    public void setFormUrl(String formUrl) {
        this.formUrl = formUrl;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public List<String> getParentFormNos() {
        return parentFormNos;
    }

    public void setParentFormNos(List<String> parentFormNos) {
        this.parentFormNos = parentFormNos;
    }

    public String getSmallType() {
        return smallType;
    }

    public void setSmallType(String smallType) {
        this.smallType = smallType;
    }
}

==> activiti-rpc-0.1.24-sources.jar: com/biz/eisp/activiti/vo/StartProcessParamVO.java <==
package com.biz.eisp.activiti.vo;

import java.io.Serializable;
import java.util.Collection;
import java.util.List;

/**
 * Created by weston on 2017/6/8.
 */
public class StartProcessParamVO implements Serializable{
    private static final long serialVersionUID = -3243637468050937453L;
    private String formNo;
    private String currentUser;
    private String costType;
    private String formType;
    private String positionCode;
    private String formUrl;
    private String title;
    private String smallType;
    private List<String> parentFormNos;

    public String printStr(){
        StringBuffer buffer = new StringBuffer();
        if(this.formNo != null){
            buffer.append(new StringBuffer(this.formNo));
        }
        if(this.currentUser != null){
            buffer.append(new StringBuffer("|").append(new StringBuffer(this.currentUser)));
        }
        if(this.costType != null){
            buffer.append(new StringBuffer("|").append(new StringBuffer(this.costType)));
        }
        if(this.formType != null){
            buffer.append(new StringBuffer("|").append(new StringBuffer(this.formType)));
        }
        if(this.positionCode != null){
            buffer.append(new StringBuffer("|").append(new StringBuffer(this.positionCode)));
        }
        if(this.formUrl != null){
            buffer.append(new StringBuffer("|").append(new StringBuffer(this.formUrl)));
        }
        if(this.title != null){
            buffer.append(new StringBuffer("|").append(new StringBuffer(this.title)));
        }
        if(this.smallType != null){
            buffer.append(new StringBuffer("|").append(new StringBuffer(this.smallType)));
        }
        buffer.append(new StringBuffer("|parentList:"));
        if(this.parentFormNos == null){
            buffer.append(new StringBuffer("null"));
        }else{
            int size = this.parentFormNos.size();
            buffer.append(new StringBuffer("size-")).append(size + "");
            if(size > 0 ){
                for (String parentFormNo : this.parentFormNos) {
                    buffer.append(new StringBuffer(",")).append(parentFormNo);
                }
            }
        }
        return buffer.toString();
    }

    public String getFormNo() {
        return formNo;
    }

    public void setFormNo(String formNo) {
        this.formNo = formNo;
    }

    public String getCurrentUser() {
        return currentUser;
    }

    public void setCurrentUser(String currentUser) {
        this.currentUser = currentUser;
    }

    public String getCostType() {
        return costType;
    }

    public void setCostType(String costType) {
        this.costType = costType;
    }

    public String getFormType() {
        return formType;
    }

    public void setFormType(String formType) {
        this.formType = formType;
    }

    public String getPositionCode() {
        return positionCode;
    }

    public void setPositionCode(String positionCode) {
        this.positionCode = positionCode;
    }

    public String getFormUrl() {
        return formUrl;
    }

    public void setFormUrl(String formUrl) {
        this.formUrl = formUrl;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public List<String> getParentFormNos() {
        return parentFormNos;
    }

    public void setParentFormNos(List<String> parentFormNos) {
        this.parentFormNos = parentFormNos;
    }

    public String getSmallType() {
        return smallType;
    }

    public void setSmallType(String smallType) {
        this.smallType = smallType;
    }
}
